Variable
========

.. currentmodule:: pqp.symbols

.. autoclass:: Variable
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Variable.to_latex

   .. rubric:: Methods Documentation

   .. automethod:: to_latex
